==> Paws-0.25.tar.gz: Paws-0.25/lib/Paws/CloudHSM/GetConfig.pm <==

package Paws::CloudHSM::GetConfig;
  use Moose;
  has ClientArn => (is => 'ro', isa => 'Str', required => 1);
  has ClientVersion => (is => 'ro', isa => 'Str', required => 1);
  has HapgList => (is => 'ro', isa => 'ArrayRef[Str]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetConfig');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CloudHSM::GetConfigResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudHSM::GetConfig - Arguments for method GetConfig on Paws::CloudHSM

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetConfig on the 
Amazon CloudHSM service. Use the attributes of this class
as arguments to method GetConfig.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetConfig.

As an example:

  $service_obj->GetConfig(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ClientArn => Str

The ARN of the client.



=head2 B<REQUIRED> ClientVersion => Str

The client version.

Valid values are: C<"5.1">, C<"5.3">

=head2 B<REQUIRED> HapgList => ArrayRef[Str]

A list of ARNs that identify the high-availability partition groups
that are associated with the client.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetConfig in L<Paws::CloudHSM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.32.tar.gz: Paws-0.32/lib/Paws/CloudHSM/GetConfig.pm <==

package Paws::CloudHSM::GetConfig;
  use Moose;
  has ClientArn => (is => 'ro', isa => 'Str', required => 1);
  has ClientVersion => (is => 'ro', isa => 'Str', required => 1);
  has HapgList => (is => 'ro', isa => 'ArrayRef[Str|Undef]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetConfig');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CloudHSM::GetConfigResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudHSM::GetConfig - Arguments for method GetConfig on Paws::CloudHSM

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetConfig on the 
Amazon CloudHSM service. Use the attributes of this class
as arguments to method GetConfig.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetConfig.

As an example:

  $service_obj->GetConfig(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ClientArn => Str

The ARN of the client.



=head2 B<REQUIRED> ClientVersion => Str

The client version.

Valid values are: C<"5.1">, C<"5.3">

=head2 B<REQUIRED> HapgList => ArrayRef[Str|Undef]

A list of ARNs that identify the high-availability partition groups
that are associated with the client.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetConfig in L<Paws::CloudHSM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
